---
sidebar_label: events_filter
title: modules.preprocessing.filters.events_filter
---

## EventsFilter Objects

```python
class EventsFilter(Experiment)
```

Events filter
Filters the events matching a certain criteria

